django\_opt\_out\.plugins package
=================================

Subpackages
-----------

.. toctree::

    django_opt_out.plugins.sparkpost

Module contents
---------------

.. automodule:: django_opt_out.plugins
    :members:
    :undoc-members:
    :show-inheritance:
